=========
Community
=========

Use these channels to communicate about the project.

Mailing list
============

The **user** mailing list is general discussion and support list for
Gunicorn users.

  * To **subscribe**, send an email to `user+subscribe@gunicorn.org
    <mailto:user+subscribe@gunicorn.org>`_
  * To **unsubscribe**, send an email to `user+unsubscribe@gunicorn.org
    <mailto:user+unsubscribe@gunicorn.org>`_
  * Finally, to post a message to the list use the address to
    `user@gunicorn.org <mailto:user@gunicorn.org>`_

The archive for this list can also be `browsed online
<http://lists.gunicorn.org/user>`_ .

Irc
===

The Gunicorn channel is on the `Freenode <http://freenode.net/>`_ IRC
network. You can chat with other on `#gunicorn channel <http://webchat.freenode.net/?channels=gunicorn>`_.

Issue Tracking
==============

Bug reports, enhancement requests and tasks generally go in the `Github
issue tracker <http://github.com/benoitc/gunicorn/issues>`_.

Security Issues
===============

The security mailing list is a place to report security issues. Only
developers are subscribed to it. To post a message to the list use the address
to `security@gunicorn.org <mailto:security@gunicorn.org>`_ .
